==> gnome-games-2.20.3-i586-1gsb.tgz: install/doinst.sh <==
if [ -x usr/bin/gconftool-2 ]; then
GCONF_CONFIG_SOURCE="$(usr/bin/gconftool-2 --get-default-source)" usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/aisleriot.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="$(usr/bin/gconftool-2 --get-default-source)" usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/blackjack.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="$(usr/bin/gconftool-2 --get-default-source)" usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/glchess.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="$(usr/bin/gconftool-2 --get-default-source)" usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/glines.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="$(usr/bin/gconftool-2 --get-default-source)" usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/gnect.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="$(usr/bin/gconftool-2 --get-default-source)" usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/gnibbles.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="$(usr/bin/gconftool-2 --get-default-source)" usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/gnobots2.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="$(usr/bin/gconftool-2 --get-default-source)" usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/gnometris.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="$(usr/bin/gconftool-2 --get-default-source)" usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/gnomine.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="$(usr/bin/gconftool-2 --get-default-source)" usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/gnotravex.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="$(usr/bin/gconftool-2 --get-default-source)" usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/gnotski.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="$(usr/bin/gconftool-2 --get-default-source)" usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/gtali.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="$(usr/bin/gconftool-2 --get-default-source)" usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/iagno.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="$(usr/bin/gconftool-2 --get-default-source)" usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/mahjongg.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="$(usr/bin/gconftool-2 --get-default-source)" usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/same-gnome.schemas >/dev/null 2>&1
fi
if [ -x usr/bin/rarian-sk-update ]; then
  usr/bin/rarian-sk-update 1> /dev/null 2> /dev/null
fi

if [ -x usr/bin/update-mime-database ]; then
  usr/bin/update-mime-database usr/share/mime 1> /dev/null 2> /dev/null
fi

if [ -x usr/bin/update-desktop-database ]; then
  usr/bin/update-desktop-database 1> /dev/null 2> /dev/null
fi

==> gnome-games-2.22.1.1-i586-1gsb.tgz: install/doinst.sh <==
if [ -x usr/bin/gconftool-2 ]; then
GCONF_CONFIG_SOURCE="$(usr/bin/gconftool-2 --get-default-source)" usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/aisleriot.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="$(usr/bin/gconftool-2 --get-default-source)" usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/blackjack.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="$(usr/bin/gconftool-2 --get-default-source)" usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/glchess.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="$(usr/bin/gconftool-2 --get-default-source)" usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/glines.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="$(usr/bin/gconftool-2 --get-default-source)" usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/gnect.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="$(usr/bin/gconftool-2 --get-default-source)" usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/gnibbles.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="$(usr/bin/gconftool-2 --get-default-source)" usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/gnobots2.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="$(usr/bin/gconftool-2 --get-default-source)" usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/gnometris.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="$(usr/bin/gconftool-2 --get-default-source)" usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/gnomine.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="$(usr/bin/gconftool-2 --get-default-source)" usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/gnotravex.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="$(usr/bin/gconftool-2 --get-default-source)" usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/gnotski.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="$(usr/bin/gconftool-2 --get-default-source)" usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/gtali.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="$(usr/bin/gconftool-2 --get-default-source)" usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/iagno.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="$(usr/bin/gconftool-2 --get-default-source)" usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/mahjongg.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="$(usr/bin/gconftool-2 --get-default-source)" usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/same-gnome.schemas >/dev/null 2>&1
fi
if [ -x usr/bin/rarian-sk-update ]; then
  usr/bin/rarian-sk-update 1> /dev/null 2> /dev/null
fi

if [ -x usr/bin/update-mime-database ]; then
  usr/bin/update-mime-database usr/share/mime 1> /dev/null 2> /dev/null
fi

if [ -x usr/bin/update-desktop-database ]; then
  usr/bin/update-desktop-database 1> /dev/null 2> /dev/null
fi

# Restart gconfd-2 if running to reload new gconf settings
if ps acx | grep -q gconfd-2 ; then
        killall -HUP gconfd-2 ;
fi
